hstrat.hstrat.stratum\_retention\_predicates.StratumRetentionPredicateFixedResolution
=====================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_predicates

.. autoclass:: StratumRetentionPredicateFixedResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionPredicateFixedResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionPredicateFixedResolution.CalcNumStrataRetainedExact
      ~StratumRetentionPredicateFixedResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionPredicateFixedResolution.CalcRankAtColumnIndex
      ~StratumRetentionPredicateFixedResolution.__init__
   
   

   
   
   